Data downloaded from hwc2.dk website, and converted to csv

k_x and k_y were 0.5, but were replaced by 1.4 so that beam2hawc2 values for K11 and K22 that match the NREL5MW BeamDyn file... This needs further investigation.
